==> CGAL-6.0.1-doc_html.tar.xz: doc_html/Manual/search/variables_b.js <==
var searchData=
[
  ['naive_0',['NAIVE',['../../Nef_2/classCGAL_1_1Nef__polyhedron__2.html#aa7cddcb2fffffe488f897da1f3cf4abcaca828eed6da20a9383aeb13ef1dcdbed',1,'CGAL::Nef_polyhedron_2']]],
  ['name_1',['name',['../../Point_set_processing_3/structCGAL_1_1IO_1_1PLY__property.html#a0a689cd48fe319db0548e5da039ba2eb',1,'CGAL::IO::PLY_property::name()'],['../../Point_set_processing_3/structCGAL_1_1pointmatcher_1_1ICP__config.html#a30540dba7014e719a42033770366c42f',1,'CGAL::pointmatcher::ICP_config::name()']]],
  ['nb_5fmarks_2',['NB_MARKS',['../../Combinatorial_map/classGenericMap.html#a6e4ee8b525afeb9bbaed065623e26e68',1,'GenericMap']]],
  ['nearest_3',['NEAREST',['../../Convex_hull_d/classCGAL_1_1Delaunay__d.html#a5dda4e3061b66c31d4597d0eaf5c1666a25753c9936ef7fdc2569b25c3e07b478',1,'CGAL::Delaunay_d']]],
  ['necorner_4',['NECORNER',['../../Nef_2/classExtendedKernelTraits__2.html#a2877caaf9a92e39e3d4d86b54d87e9cca817c4b3a5bf04e644b0f58890b71d5df',1,'ExtendedKernelTraits_2']]],
  ['negative_5',['NEGATIVE',['../../Kernel_23/group__kernel__enums.html#gga59bee58a806ccde81562ea315ff75525a3aef56502334293e3ad25e166d74bb2a',1,'CGAL']]],
  ['neutral_6',['NEUTRAL',['../../Classification/classCGAL_1_1Classification_1_1Sum__of__weighted__features__classifier.html#a6aab054f8adf32f1e05b693f5caf9512aafe5766bc7d9202e9e856491e311d954',1,'CGAL::Classification::Sum_of_weighted_features_classifier']]],
  ['next_5flink_7',['next_link',['../../STL_Extension/classCGAL_1_1In__place__list__base.html#a9c38816da3cc9a9e88ee0e44f2e64c0b',1,'CGAL::In_place_list_base']]],
  ['no_5fboundary_5floc_8',['NO_BOUNDARY_LOC',['../../Arrangement_on_surface_2/classCGAL_1_1Arr__geodesic__arc__on__sphere__traits__2_1_1Point__2.html#af0dde2a283f82a95b50cab1a5574d271a43227f2d340bd1ab382d0e778a4644d0',1,'CGAL::Arr_geodesic_arc_on_sphere_traits_2::Point_2']]],
  ['no_5foption_9',['NO_OPTION',['../../Surface_mesher/group__PkgSurfaceMesher3FunctionsIO.html#gga79944e81075ea1199fe75e255d7d3393ab71f5a6087bb47b8fe9e7a7503b48603',1,'CGAL::Surface_mesher::NO_OPTION()'],['../../Surface_mesher/group__PkgSurfaceMesher3FunctionsIO.html#gga79944e81075ea1199fe75e255d7d3393ab71f5a6087bb47b8fe9e7a7503b48603',1,'CGAL::Surface_mesher::NO_OPTION()']]],
  ['non_5fgeneric_5fumbilic_10',['NON_GENERIC_UMBILIC',['../../Ridges_3/group__PkgRidges3Enums.html#gga4a6962972d77b9dcc9dfd82fdb5cf822a34921ace95210d956a9ba2c8615933a7',1,'CGAL']]],
  ['normal_11',['NORMAL',['../../Circular_kernel_3/group__PkgCircularKernel3GeometricClasses.html#gga60d9863f63464a769af1e95c50d3f89aad2142aea5a2f6926c204b9ee37b87179',1,'CGAL::NORMAL()'],['../../Circular_kernel_3/group__PkgCircularKernel3GeometricClasses.html#gga60d9863f63464a769af1e95c50d3f89aad2142aea5a2f6926c204b9ee37b87179',1,'CGAL::NORMAL()']]],
  ['normal_5fthreshold_12',['normal_threshold',['../../Shape_detection/structCGAL_1_1Shape__detection_1_1Efficient__RANSAC_1_1Parameters.html#a4da6cd7c6d2894e58a98a998b043784d',1,'CGAL::Shape_detection::Efficient_RANSAC::Parameters']]],
  ['not_5fbad_13',['NOT_BAD',['../../Mesh_2/group__PkgMesh2Ref.html#gga6d26ab50a4dcc8432e7090d8f6acdd84a66610c888593bd07717c922eb69a5746',1,'CGAL::Mesh_2::NOT_BAD()'],['../../Mesh_2/group__PkgMesh2Ref.html#gga6d26ab50a4dcc8432e7090d8f6acdd84a66610c888593bd07717c922eb69a5746',1,'CGAL::Mesh_2::NOT_BAD()']]],
  ['not_5fin_5fcomplex_14',['NOT_IN_COMPLEX',['../../Surface_mesher/classSurfaceMeshComplex__2InTriangulation__3.html#a766ad070d52d32f43bf82f2d5ea00b07a68437c73df6fd96c75c0c15ae52db8f4',1,'SurfaceMeshComplex_2InTriangulation_3']]],
  ['not_5fon_5fsphere_15',['NOT_ON_SPHERE',['../../Triangulation_on_sphere_2/classCGAL_1_1Triangulation__on__sphere__2.html#a1380bd7cd4c609ad52833f5e62778368a8e685483f2b164f1fbaacd5b26b0d570',1,'CGAL::Triangulation_on_sphere_2']]],
  ['null_5fdart_5fdescriptor_16',['null_dart_descriptor',['../../Combinatorial_map/classCombinatorialMap.html#ac84ba0cfc4de9f6caf6479b76d35c520',1,'CombinatorialMap']]],
  ['null_5fdescriptor_17',['null_descriptor',['../../Combinatorial_map/classGenericMap.html#a318509a3b40cbbf2e63d16af64567a4c',1,'GenericMap']]],
  ['null_5fvector_18',['NULL_VECTOR',['../../Kernel_23/group__kernel__enums.html#ga4a98ec6bd9dfd8fe8c46fea553b5d238',1,'CGAL']]],
  ['number_5fof_5funremovable_5fvertices_19',['number_of_unremovable_vertices',['../../Polyline_simplification_2/classCGAL_1_1Polyline__simplification__2_1_1Polyline__simplification__2.html#a51251f17151287df96a27b49d58ef9b2',1,'CGAL::Polyline_simplification_2::Polyline_simplification_2']]],
  ['nwcorner_20',['NWCORNER',['../../Nef_2/classExtendedKernelTraits__2.html#a2877caaf9a92e39e3d4d86b54d87e9cca815c1bf793c732a575ffed47e1bacf4d',1,'ExtendedKernelTraits_2']]]
];

==> CGAL-6.1-doc_html.tar.xz: doc_html/Manual/search/variables_b.js <==
var searchData=
[
  ['naive_0',['NAIVE',['../../Nef_2/classCGAL_1_1Nef__polyhedron__2.html#aa7cddcb2fffffe488f897da1f3cf4abcaca828eed6da20a9383aeb13ef1dcdbed',1,'CGAL::Nef_polyhedron_2']]],
  ['name_1',['name',['../../Point_set_processing_3/structCGAL_1_1IO_1_1PLY__property.html#a0a689cd48fe319db0548e5da039ba2eb',1,'CGAL::IO::PLY_property::name()'],['../../Point_set_processing_3/structCGAL_1_1pointmatcher_1_1ICP__config.html#a30540dba7014e719a42033770366c42f',1,'CGAL::pointmatcher::ICP_config::name()']]],
  ['nb_5fmarks_2',['NB_MARKS',['../../Combinatorial_map/classGenericMap.html#a6e4ee8b525afeb9bbaed065623e26e68',1,'GenericMap']]],
  ['nearest_3',['NEAREST',['../../Convex_hull_d/classCGAL_1_1Delaunay__d.html#a5dda4e3061b66c31d4597d0eaf5c1666a25753c9936ef7fdc2569b25c3e07b478',1,'CGAL::Delaunay_d']]],
  ['necorner_4',['NECORNER',['../../Nef_2/classExtendedKernelTraits__2.html#a2877caaf9a92e39e3d4d86b54d87e9cca817c4b3a5bf04e644b0f58890b71d5df',1,'ExtendedKernelTraits_2']]],
  ['negative_5',['NEGATIVE',['../../Kernel_23/group__kernel__enums.html#gga59bee58a806ccde81562ea315ff75525a3aef56502334293e3ad25e166d74bb2a',1,'CGAL']]],
  ['neutral_6',['NEUTRAL',['../../Classification/classCGAL_1_1Classification_1_1Sum__of__weighted__features__classifier.html#a6aab054f8adf32f1e05b693f5caf9512aafe5766bc7d9202e9e856491e311d954',1,'CGAL::Classification::Sum_of_weighted_features_classifier']]],
  ['next_5flink_7',['next_link',['../../STL_Extension/classCGAL_1_1In__place__list__base.html#a9c38816da3cc9a9e88ee0e44f2e64c0b',1,'CGAL::In_place_list_base']]],
  ['no_5fboundary_5floc_8',['NO_BOUNDARY_LOC',['../../Arrangement_on_surface_2/classCGAL_1_1Arr__geodesic__arc__on__sphere__traits__2_1_1Point__2.html#af0dde2a283f82a95b50cab1a5574d271a43227f2d340bd1ab382d0e778a4644d0',1,'CGAL::Arr_geodesic_arc_on_sphere_traits_2::Point_2']]],
  ['no_5foption_9',['NO_OPTION',['../../Surface_mesher/group__PkgSurfaceMesher3FunctionsIO.html#gga79944e81075ea1199fe75e255d7d3393ab71f5a6087bb47b8fe9e7a7503b48603',1,'CGAL::Surface_mesher::NO_OPTION()'],['../../Surface_mesher/group__PkgSurfaceMesher3FunctionsIO.html#gga79944e81075ea1199fe75e255d7d3393ab71f5a6087bb47b8fe9e7a7503b48603',1,'CGAL::Surface_mesher::NO_OPTION()']]],
  ['non_5fgeneric_5fumbilic_10',['NON_GENERIC_UMBILIC',['../../Ridges_3/group__PkgRidges3Enums.html#gga4a6962972d77b9dcc9dfd82fdb5cf822a34921ace95210d956a9ba2c8615933a7',1,'CGAL']]],
  ['normal_11',['NORMAL',['../../Circular_kernel_3/group__PkgCircularKernel3GeometricClasses.html#gga60d9863f63464a769af1e95c50d3f89aad2142aea5a2f6926c204b9ee37b87179',1,'CGAL::NORMAL()'],['../../Circular_kernel_3/group__PkgCircularKernel3GeometricClasses.html#gga60d9863f63464a769af1e95c50d3f89aad2142aea5a2f6926c204b9ee37b87179',1,'CGAL::NORMAL()']]],
  ['normal_5fthreshold_12',['normal_threshold',['../../Shape_detection/structCGAL_1_1Shape__detection_1_1Efficient__RANSAC_1_1Parameters.html#a4da6cd7c6d2894e58a98a998b043784d',1,'CGAL::Shape_detection::Efficient_RANSAC::Parameters']]],
  ['not_5fbad_13',['NOT_BAD',['../../Mesh_2/group__PkgMesh2Ref.html#gga6d26ab50a4dcc8432e7090d8f6acdd84a66610c888593bd07717c922eb69a5746',1,'CGAL::Mesh_2::NOT_BAD()'],['../../Mesh_2/group__PkgMesh2Ref.html#gga6d26ab50a4dcc8432e7090d8f6acdd84a66610c888593bd07717c922eb69a5746',1,'CGAL::Mesh_2::NOT_BAD()']]],
  ['not_5fin_5fcomplex_14',['NOT_IN_COMPLEX',['../../Surface_mesher/classSurfaceMeshComplex__2InTriangulation__3.html#a766ad070d52d32f43bf82f2d5ea00b07a68437c73df6fd96c75c0c15ae52db8f4',1,'SurfaceMeshComplex_2InTriangulation_3']]],
  ['not_5fon_5fsphere_15',['NOT_ON_SPHERE',['../../Triangulation_on_sphere_2/classCGAL_1_1Triangulation__on__sphere__2.html#a1380bd7cd4c609ad52833f5e62778368a8e685483f2b164f1fbaacd5b26b0d570',1,'CGAL::Triangulation_on_sphere_2']]],
  ['null_5fdart_5fdescriptor_16',['null_dart_descriptor',['../../Combinatorial_map/classCombinatorialMap.html#ac84ba0cfc4de9f6caf6479b76d35c520',1,'CombinatorialMap']]],
  ['null_5fdescriptor_17',['null_descriptor',['../../Combinatorial_map/classGenericMap.html#a318509a3b40cbbf2e63d16af64567a4c',1,'GenericMap']]],
  ['null_5fvector_18',['NULL_VECTOR',['../../Kernel_23/group__kernel__enums.html#ga4a98ec6bd9dfd8fe8c46fea553b5d238',1,'CGAL']]],
  ['number_5fof_5foperations_19',['NUMBER_OF_OPERATIONS',['../../Arrangement_on_surface_2/classCGAL_1_1Arr__tracing__traits__2.html#a3014ee1c958ef140b6850fe89fb2fd23aa207978499c553c1657dda1858777ea1',1,'CGAL::Arr_tracing_traits_2::NUMBER_OF_OPERATIONS()'],['../../Arrangement_on_surface_2/classCGAL_1_1Arr__counting__traits__2.html#aedf884b9364a81a9ad031989841d494bad772975ef4e124091b08b389fa6af3c5',1,'CGAL::Arr_counting_traits_2::NUMBER_OF_OPERATIONS()']]],
  ['number_5fof_5funremovable_5fvertices_20',['number_of_unremovable_vertices',['../../Polyline_simplification_2/classCGAL_1_1Polyline__simplification__2_1_1Polyline__simplification__2.html#a51251f17151287df96a27b49d58ef9b2',1,'CGAL::Polyline_simplification_2::Polyline_simplification_2']]],
  ['nwcorner_21',['NWCORNER',['../../Nef_2/classExtendedKernelTraits__2.html#a2877caaf9a92e39e3d4d86b54d87e9cca815c1bf793c732a575ffed47e1bacf4d',1,'ExtendedKernelTraits_2']]]
];
